@@ -25,8 +25,8 @@
  * ԥ
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.13 $
- * $Date: 2012/09/19 00:02:18 $
+ * $Revision: 1.14 $
+ * $Date: 2013/07/23 06:45:20 $
  *
  **********************************************************/
 include_once("lib/dglibcommon");
@@ -77,7 +77,7 @@ if (isset($_POST["login"]) === TRUE) {
 
     /* ̾Υå */
     if (check_admin_uname($_POST["admin"], MAXADMINNAME) === TRUE &&
-        check_passwd($_POST["passwd"], MINPASSWD, MAXADMINPASS) === TRUE) {
+        check_passwd($_POST["passwd"], MINADMINPASSWD, MAXADMINPASSWD) === TRUE) {
         /* åå& */
         if (sess_start($_POST["admin"], $_POST["passwd"], $sesskey) === TRUE) {
             result_log(OPERATION_LOGIN . ":OK:" . $msgarr['05006'][LOG_MSG]);
